@@ -2,7 +2,7 @@ package Test::TCP;
 use strict;
 use warnings;
 use 5.00800;
-our $VERSION = '1.10';
+our $VERSION = '1.12';
 use base qw/Exporter/;
 use IO::Socket::INET;
 use Test::SharedFork 0.12;
@@ -108,12 +108,16 @@ sub start {
     my $self = shift;
     if ( my $pid = fork() ) {
         # parent.
-        Test::TCP::wait_port($self->port);
         $self->{pid} = $pid;
+        Test::TCP::wait_port($self->port);
         return;
     } elsif ($pid == 0) {
         # child process
         $self->{code}->($self->port);
+        # should not reach here
+        if (kill 0, $self->{_my_pid}) { # warn only parent process still exists
+            warn("[Test::TCP] Child process does not block(PID: $$, PPID: $self->{_my_pid})");
+        }
         exit 0;
     } else {
         die "fork failed: $!";
@@ -147,6 +151,7 @@ sub stop {
 
 sub DESTROY {
     my $self = shift;
+    local $@;
     $self->stop();
 }
 
@@ -161,6 +166,34 @@ Test::TCP - testing TCP program
 
 =head1 SYNOPSIS
 
+    use Test::TCP;
+
+    my $server = Test::TCP->new(
+        code => sub {
+            my $port = shift;
+            ...
+        },
+    );
+    my $client = MyClient->new(host => '127.0.0.1', port => $server->port);
+    undef $server; # kill child process on DESTROY
+
+Using memcached:
+
+    use Test::TCP;
+
+    my $memcached = Test::TCP->new(
+        code => sub {
+            my $port = shift;
+
+            exec $bin, '-p' => $port;
+            die "cannot execute $bin: $!";
+        },
+    );
+    my $memd = Cache::Memcached->new({servers => ['127.0.0.1:' . $memcached->port]});
+    ...
+
+And functional interface is available:
+
     use Test::TCP;
     test_tcp(
         client => sub {
@@ -173,35 +206,9 @@ Test::TCP - testing TCP program
         },
     );
 
-using other server program
-
-    use Test::TCP;
-    test_tcp(
-        client => sub {
-            my $port = shift;
-            # send request to the server
-        },
-        server => sub {
-            exec '/foo/bar/bin/server', 'options';
-        },
-    );
-
-Or, OO-ish interface
-
-    use Test::TCP;
-
-    my $server = Test::TCP->new(
-        code => sub {
-            my $port = shift;
-            ...
-        },
-    );
-    my $client = MyClient->new(host => '127.0.0.1', port => $server->port);
-    undef $server; # kill child process on DESTROY
-
 =head1 DESCRIPTION
 
-Test::TCP is test utilities for TCP/IP program.
+Test::TCP is test utilities for TCP/IP programs.
 
 =head1 METHODS
 
@@ -215,6 +222,8 @@ Get the available port number, you can use.
 
 =item test_tcp
 
+Functional interface.
+
     test_tcp(
         client => sub {
             my $port = shift;
